@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@ Copyright_License {
 
 #include "ActionInterface.hpp"
 #include "Interface.hpp"
-#include "Thread/Mutex.hpp"
+#include "thread/Mutex.hxx"
 #include "MainWindow.hpp"
 #include "Projection/MapWindowProjection.hpp"
 #include "Language/Language.hpp"
@@ -47,7 +47,7 @@ void
 XCSoarInterface::ReceiveGPS()
 {
   {
-    ScopeLock protect(device_blackboard->mutex);
+    std::lock_guard<Mutex> lock(device_blackboard->mutex);
 
     ReadBlackboardBasic(device_blackboard->Basic());
 
@@ -67,7 +67,7 @@ void
 XCSoarInterface::ReceiveCalculated()
 {
   {
-    ScopeLock protect(device_blackboard->mutex);
+    std::lock_guard<Mutex> lock(device_blackboard->mutex);
 
     ReadBlackboardCalculated(device_blackboard->Calculated());
     device_blackboard->ReadComputerSettings(GetComputerSettings());
@@ -87,7 +87,7 @@ XCSoarInterface::ExchangeBlackboard()
 void
 XCSoarInterface::ExchangeDeviceBlackboard()
 {
-  ScopeLock protect(device_blackboard->mutex);
+  std::lock_guard<Mutex> lock(device_blackboard->mutex);
 
   device_blackboard->ReadComputerSettings(GetComputerSettings());
 }
@@ -104,7 +104,7 @@ ActionInterface::SendGetComputerSettings()
 }
 
 void
-ActionInterface::SetBallast(fixed ballast, bool to_devices)
+ActionInterface::SetBallast(double ballast, bool to_devices)
 {
   // write ballast into settings
   GlidePolar &polar = SetComputerSettings().polar.glide_polar_task;
@@ -122,8 +122,8 @@ ActionInterface::SetBallast(fixed ballast, bool to_devices)
   // send to external devices
   if (to_devices) {
     const Plane &plane = GetComputerSettings().plane;
-    if (positive(plane.dry_mass)) {
-      fixed overload = (plane.dry_mass + ballast * plane.max_ballast) /
+    if (plane.dry_mass > 0) {
+      auto overload = (plane.dry_mass + ballast * plane.max_ballast) /
         plane.dry_mass;
 
       MessageOperationEnvironment env;
@@ -133,7 +133,7 @@ ActionInterface::SetBallast(fixed ballast, bool to_devices)
 }
 
 void
-ActionInterface::SetBugs(fixed bugs, bool to_devices)
+ActionInterface::SetBugs(double bugs, bool to_devices)
 {
   // Write Bugs into settings
   CommonInterface::SetComputerSettings().polar.SetBugs(bugs);
@@ -156,14 +156,14 @@ ActionInterface::SetBugs(fixed bugs, bool to_devices)
 }
 
 void
-ActionInterface::SetMacCready(fixed mc, bool to_devices)
+ActionInterface::SetMacCready(double mc, bool to_devices)
 {
   // Repeated adjustment of MC with the +/- UI elements could result in
   // an MC which is slightly larger than 0. Since the calculations
   // fundamentally change depending on  "MC == 0" or "MC <> 0" force
-  // a fixed(0) for small MC values.
-  if (mc < fixed(0.01))
-    mc = fixed(0);
+  // a 0 for small MC values.
+  if (mc < 0.01)
+    mc = 0;
 
   /* update interface settings */
 
@@ -192,7 +192,7 @@ ActionInterface::SetMacCready(fixed mc, bool to_devices)
   }
 }
 
-void ActionInterface::SetManualMacCready(fixed mc, bool to_devices)
+void ActionInterface::SetManualMacCready(double mc, bool to_devices)
 {
   TaskBehaviour &task_behaviour = CommonInterface::SetComputerSettings().task;
   if (task_behaviour.auto_mc) {
@@ -204,15 +204,15 @@ void ActionInterface::SetManualMacCready(fixed mc, bool to_devices)
 }
 
 void
-ActionInterface::OffsetManualMacCready(fixed offset, bool to_devices)
+ActionInterface::OffsetManualMacCready(double offset, bool to_devices)
 {
   const GlidePolar &polar = GetComputerSettings().polar.glide_polar_task;
-  const fixed old_mc = polar.GetMC();
-  fixed mc = old_mc + offset;
-  if (negative(mc))
-    mc = fixed(0);
-  else if (mc > fixed(5))
-    mc = fixed(5);
+  const auto old_mc = polar.GetMC();
+  auto mc = old_mc + offset;
+  if (mc < 0)
+    mc = 0;
+  else if (mc > 5)
+    mc = 5;
 
   if (mc != old_mc)
     SetManualMacCready(mc, to_devices);
@@ -291,3 +291,86 @@ ActionInterface::SendUIState()
 
   main_window->SetUIState(GetUIState());
 }
+
+void
+ActionInterface::SetActiveFrequency(const RadioFrequency & freq, const TCHAR * freq_name, bool to_devices)
+{
+  /* update interface settings */
+
+  SetComputerSettings().radio.active_frequency = freq;
+  if(freq_name != nullptr) {
+    SetComputerSettings().radio.active_name = freq_name;
+  }
+  else {
+    SetComputerSettings().radio.active_name.clear();
+  }
+
+  /* update InfoBoxes (that might show the ActiveFrequency setting) */
+
+  InfoBoxManager::SetDirty();
+
+  /* send to external devices */
+
+  if (to_devices) {
+    MessageOperationEnvironment env;
+    device_blackboard->SetActiveFrequency(freq, freq_name, env);
+  }
+}
+
+void
+ActionInterface::SetStandbyFrequency(const RadioFrequency & freq, const TCHAR * freq_name, bool to_devices)
+{
+  /* update interface settings */
+
+  SetComputerSettings().radio.standby_frequency = freq;
+  if(freq_name != nullptr) {
+    SetComputerSettings().radio.standby_name = freq_name;
+  }
+  else {
+    SetComputerSettings().radio.standby_name.clear();
+  }
+
+  /* update InfoBoxes (that might show the ActiveFrequency setting) */
+
+  InfoBoxManager::SetDirty();
+
+  /* send to external devices */
+
+  if (to_devices) {
+    MessageOperationEnvironment env;
+    device_blackboard->SetStandbyFrequency(freq, freq_name, env);
+  }
+}
+
+void ActionInterface::OffsetActiveFrequency(double offset_khz, bool to_devices)
+{
+  RadioFrequency new_active_freq = SetComputerSettings().radio.active_frequency;
+  if(new_active_freq.IsDefined()) {
+    new_active_freq.OffsetKiloHertz(offset_khz);
+    if(new_active_freq.IsDefined()) {
+      ActionInterface::SetActiveFrequency(new_active_freq, nullptr, to_devices);
+    }
+  }
+}
+
+void ActionInterface::OffsetStandbyFrequency(double offset_khz, bool to_devices)
+{
+  RadioFrequency new_standby_freq = SetComputerSettings().radio.standby_frequency;
+  if(new_standby_freq.IsDefined()) {
+    new_standby_freq.OffsetKiloHertz(offset_khz);
+    if(new_standby_freq.IsDefined()) {
+      ActionInterface::SetStandbyFrequency(new_standby_freq, nullptr, to_devices);
+    }
+  }
+}
+
+void ActionInterface::ExchangeRadioFrequencies(bool to_devices)
+{
+  const auto radio_settings = SetComputerSettings().radio;
+
+  const auto old_active_freq = radio_settings.active_frequency;
+  const auto old_active_freq_name = radio_settings.active_name;
+
+  ActionInterface::SetActiveFrequency(radio_settings.standby_frequency, radio_settings.standby_name, to_devices);
+  ActionInterface::SetStandbyFrequency(old_active_freq, old_active_freq_name, to_devices);
+}
