@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -27,22 +27,20 @@ Copyright_License {
 #include "Operation/Operation.hpp"
 #include "Units/System.hpp"
 #include "Language/Language.hpp"
-#include "Util/CharUtil.hpp"
-#include "Util/StringUtil.hpp"
-#include "Util/StringAPI.hxx"
-#include "Util/NumberParser.hpp"
-#include "Util/Macros.hpp"
+#include "util/CharUtil.hxx"
+#include "util/StringAPI.hxx"
+#include "util/StringParser.hxx"
+#include "util/Macros.hpp"
 #include "Geo/Math.hpp"
-#include "IO/LineReader.hpp"
+#include "io/LineReader.hpp"
 #include "Airspace/AirspacePolygon.hpp"
 #include "Airspace/AirspaceCircle.hpp"
 #include "Geo/GeoVector.hpp"
 #include "Engine/Airspace/AirspaceClass.hpp"
-#include "Util/StaticString.hxx"
+#include "util/StaticString.hxx"
+#include "util/StringCompare.hxx"
 
 #include <tchar.h>
-#include <stdio.h>
-#include <stdlib.h>
 
 enum class AirspaceFileType {
   UNKNOWN,
@@ -137,7 +135,7 @@ struct TempAirspaceType
 
   // Circle or Arc
   GeoPoint center;
-  fixed radius;
+  double radius;
 
   // Arc
   int rotation;
@@ -153,7 +151,7 @@ struct TempAirspaceType
     center.longitude = Angle::Zero();
     center.latitude = Angle::Zero();
     rotation = 1;
-    radius = fixed(0);
+    radius = 0;
   }
 
   void
@@ -164,7 +162,7 @@ struct TempAirspaceType
     center.longitude = Angle::Zero();
     center.latitude = Angle::Zero();
     rotation = 1;
-    radius = fixed(0);
+    radius = 0;
   }
 
   void
@@ -191,13 +189,13 @@ struct TempAirspaceType
   }
 
   static int
-  ArcStepWidth(fixed radius)
+  ArcStepWidth(double radius)
   {
-    if (radius > fixed(50000))
+    if (radius > 50000)
       return 1;
-    if (radius > fixed(25000))
+    if (radius > 25000)
       return 2;
-    if (radius > fixed(10000))
+    if (radius > 10000)
       return 3;
 
     return 5;
@@ -210,12 +208,12 @@ struct TempAirspaceType
     // Determine start bearing and radius
     const GeoVector v = center.DistanceBearing(start);
     Angle start_bearing = v.bearing;
-    const fixed radius = v.distance;
+    const auto radius = v.distance;
 
     // 5 or -5, depending on direction
     const auto _step = ArcStepWidth(radius);
-    const Angle step = Angle::Degrees(rotation * _step);
-    const fixed threshold = _step * fixed(1.5);
+    const auto step = Angle::Degrees(rotation * _step);
+    const auto threshold = _step * 1.5;
 
     // Determine end bearing
     Angle end_bearing = center.Bearing(end);
@@ -246,8 +244,8 @@ struct TempAirspaceType
   {
     // 5 or -5, depending on direction
     const auto _step = ArcStepWidth(radius);
-    const Angle step = Angle::Degrees(rotation * _step);
-    const fixed threshold = _step * fixed(1.5);
+    const auto step = Angle::Degrees(rotation * _step);
+    const auto threshold = _step * 1.5;
 
     if (rotation > 0) {
       while (end < start)
@@ -282,53 +280,39 @@ ShowParseWarning(int line, const TCHAR *str, OperationEnvironment &operation)
 }
 
 static void
-ReadAltitude(const TCHAR *buffer, AirspaceAltitude &altitude)
+ReadAltitude(StringParser<TCHAR> &input, AirspaceAltitude &altitude)
 {
-  Unit unit = Unit::FEET;
+  auto unit = Unit::FEET;
   enum { MSL, AGL, SFC, FL, STD, UNLIMITED } type = MSL;
-  fixed value = fixed(0);
+  double value = 0;
 
-  const TCHAR *p = buffer;
   while (true) {
-    while (*p == _T(' '))
-      ++p;
+    input.Strip();
 
-    if (IsDigitASCII(*p)) {
-      TCHAR *endptr;
-      value = fixed(ParseDouble(p, &endptr));
-      p = endptr;
-    } else if (StringIsEqualIgnoreCase(p, _T("GND"), 3) ||
-               StringIsEqualIgnoreCase(p, _T("AGL"), 3)) {
+    if (IsDigitASCII(input.front())) {
+      input.ReadDouble(value);
+    } else if (input.SkipMatchIgnoreCase(_T("GND"), 3) ||
+               input.SkipMatchIgnoreCase(_T("AGL"), 3)) {
       type = AGL;
-      p += 3;
-    } else if (StringIsEqualIgnoreCase(p, _T("SFC"), 3)) {
+    } else if (input.SkipMatchIgnoreCase(_T("SFC"), 3)) {
       type = SFC;
-      p += 3;
-    } else if (StringIsEqualIgnoreCase(p, _T("FL"), 2)) {
+    } else if (input.SkipMatchIgnoreCase(_T("FL"), 2)) {
       type = FL;
-      p += 2;
-    } else if (*p == _T('F') || *p == _T('f')) {
+    } else if (input.SkipMatchIgnoreCase(_T("FT"), 2)) {
       unit = Unit::FEET;
-      ++p;
-
-      if (*p == _T('T') || *p == _T('t'))
-        ++p;
-    } else if (StringIsEqualIgnoreCase(p, _T("MSL"), 3)) {
+    } else if (input.SkipMatchIgnoreCase(_T("MSL"), 3)) {
       type = MSL;
-      p += 3;
-    } else if (*p == _T('M') || *p == _T('m')) {
+    } else if (input.front() == _T('M') || input.front() == _T('m')) {
       unit = Unit::METER;
-      ++p;
-    } else if (StringIsEqualIgnoreCase(p, _T("STD"), 3)) {
+      input.Skip();
+    } else if (input.SkipMatchIgnoreCase(_T("STD"), 3)) {
       type = STD;
-      p += 3;
-    } else if (StringIsEqualIgnoreCase(p, _T("UNL"), 3)) {
+    } else if (input.SkipMatchIgnoreCase(_T("UNL"), 3)) {
       type = UNLIMITED;
-      p += 3;
-    } else if (*p == _T('\0'))
+    } else if (input.IsEmpty())
       break;
     else
-      ++p;
+      input.Skip();
   }
 
   switch (type) {
@@ -342,15 +326,15 @@ ReadAltitude(const TCHAR *buffer, AirspaceAltitude &altitude)
 
   case UNLIMITED:
     altitude.reference = AltitudeReference::MSL;
-    altitude.altitude = fixed(50000);
+    altitude.altitude = 50000;
     return;
 
   case SFC:
     altitude.reference = AltitudeReference::AGL;
-    altitude.altitude_above_terrain = fixed(-1);
+    altitude.altitude_above_terrain = -1;
 
     /* prepare fallback, just in case we have no terrain */
-    altitude.altitude = fixed(0);
+    altitude.altitude = 0;
     return;
 
   default:
@@ -390,118 +374,111 @@ ReadAltitude(const TCHAR *buffer, AirspaceAltitude &altitude)
  * @return the non-negative angle or a negative value on error
  */
 static Angle
-ReadNonNegativeAngle(const TCHAR *p, double max_degrees, TCHAR **endptr_r)
+ReadNonNegativeAngle(StringParser<TCHAR> &input, double max_degrees)
 {
-  TCHAR *endptr;
+  double degrees;
+  if (!input.ReadDouble(degrees) || degrees < 0 || degrees > max_degrees)
+    return Angle::Native(-1);
 
-  double degrees = ParseDouble(p, &endptr);
-  if (endptr == p || degrees < 0 || degrees > max_degrees)
-    return Angle::Native(fixed(-1));
-
-  if (*endptr == ':') {
-    p = endptr + 1;
-    double minutes = ParseDouble(p, &endptr);
-    if (endptr == p || minutes < 0 || minutes > 60)
-      return Angle::Native(fixed(-1));
+  if (input.SkipMatch(':')) {
+    double minutes;
+    if (!input.ReadDouble(minutes) || minutes < 0 || minutes > 60)
+      return Angle::Native(-1);
 
     degrees += minutes / 60;
 
-    if (*endptr == ':') {
-      p = endptr + 1;
-      double seconds = ParseDouble(p, &endptr);
-      if (endptr == p || seconds < 0 || seconds > 60)
-        return Angle::Native(fixed(-1));
+    if (input.SkipMatch(':')) {
+      double seconds;
+      if (!input.ReadDouble(seconds) || seconds < 0 || seconds > 60)
+        return Angle::Native(-1);
 
       degrees += seconds / 3600;
     }
   }
 
-  *endptr_r = endptr;
   return Angle::Degrees(degrees);
 }
 
 static bool
-ReadCoords(const TCHAR *buffer, GeoPoint &point)
+ReadCoords(StringParser<TCHAR> &input, GeoPoint &point)
 {
   // Format: 53:20:41 N 010:24:41 E
   // Alternative Format: 53:20.68 N 010:24.68 E
 
-  TCHAR *endptr;
+  auto angle = ReadNonNegativeAngle(input, 91);
+  if (angle.IsNegative())
+    return false;
 
-  auto angle = ReadNonNegativeAngle(buffer, 91, &endptr);
-  if (negative(angle.Native()))
+  input.Strip();
+  if (input.SkipMatch('S') || input.SkipMatch('s'))
+    angle.Flip();
+  else if (!input.SkipMatch('N') && !input.SkipMatch('n'))
     return false;
 
   point.latitude = angle;
 
-  if (*endptr == ' ')
-    endptr++;
-
-  if (*endptr == '\0')
+  angle = ReadNonNegativeAngle(input, 181);
+  if (angle.IsNegative())
     return false;
 
-  if ((*endptr == 'S') || (*endptr == 's'))
-    point.latitude.Flip();
-
-  endptr++;
-  if (*endptr == '\0')
-    return false;
-
-  buffer = endptr;
-  angle = ReadNonNegativeAngle(buffer, 181, &endptr);
-  if (negative(angle.Native()))
+  input.Strip();
+  if (input.SkipMatch('W') || input.SkipMatch('w'))
+    angle.Flip();
+  else if (!input.SkipMatch('E') && !input.SkipMatch('e'))
     return false;
 
   point.longitude = angle;
 
-  if (*endptr == ' ')
-    endptr++;
-
-  if (*endptr == '\0')
-    return false;
-
-  if ((*endptr == 'W') || (*endptr == 'w'))
-    point.longitude.Flip();
-
   point.Normalize(); // ensure longitude is within -180:180
   return true;
 }
 
-static Angle
-ParseBearingDegrees(const TCHAR *p, TCHAR **endptr=nullptr)
+static bool
+ParseBearingDegrees(StringParser<TCHAR> &input, Angle &value_r)
 {
-  return Angle::Degrees(ParseDouble(p, endptr)).AsBearing();
-}
+  double value;
+  if (!input.ReadDouble(value) || value < 0 || value > 361)
+    return false;
 
-static void
-ParseArcBearings(const TCHAR *buffer, TempAirspaceType &temp_area)
-{
-  // Determine radius and start/end bearing
-  TCHAR *endptr;
-  temp_area.radius = Units::ToSysUnit(fixed(ParseDouble(&buffer[2], &endptr)),
-                                      Unit::NAUTICAL_MILES);
-  Angle start_bearing = ParseBearingDegrees(&endptr[1], &endptr);
-  Angle end_bearing = ParseBearingDegrees(&endptr[1], &endptr);
-
-  temp_area.AppendArc(start_bearing, end_bearing);
+  value_r = Angle::Degrees(value).AsBearing();
+  return true;
 }
 
 static bool
-ParseArcPoints(const TCHAR *buffer, TempAirspaceType &temp_area)
+ParseArcBearings(StringParser<TCHAR> &input, TempAirspaceType &temp_area)
+{
+  // Determine radius and start/end bearing
+
+  double radius;
+  if (!input.ReadDouble(radius) || radius <= 0 || radius > 1000)
+    return false;
+
+  temp_area.radius = Units::ToSysUnit(radius, Unit::NAUTICAL_MILES);
+  Angle start_bearing, end_bearing;
+  if (!ParseBearingDegrees(input, start_bearing) ||
+      !ParseBearingDegrees(input, end_bearing))
+    return false;
+
+  temp_area.AppendArc(start_bearing, end_bearing);
+  return true;
+}
+
+static bool
+ParseArcPoints(StringParser<TCHAR> &input, TempAirspaceType &temp_area)
 {
   // Read start coordinates
   GeoPoint start;
-  if (!ReadCoords(&buffer[3], start))
+  if (!ReadCoords(input, start))
     return false;
 
   // Skip comma character
-  const auto *comma = StringFind(buffer, ',');
-  if (!comma)
+  input.Strip();
+  if (!input.SkipMatch(','))
     return false;
 
   // Read end coordinates
   GeoPoint end;
-  if (!ReadCoords(&comma[1], end))
+  if (!ReadCoords(input, end))
     return false;
 
   temp_area.AppendArc(start, end);
@@ -518,54 +495,25 @@ ParseType(const TCHAR *buffer)
   return OTHER;
 }
 
-/**
- * Returns the value of the specified line, after a space character
- * which is skipped.  If the input is empty (without a leading space),
- * an empty string is returned, as a special case to work around
- * broken input files.
- *
- * @return the first character of the value, or nullptr if the input is
- * malformed
- */
-static const TCHAR *
-ValueAfterSpace(const TCHAR *p)
-{
-  if (StringIsEmpty(p))
-    return p;
-
-  if (*p != _T(' '))
-    /* not a space: must be a malformed line */
-    return nullptr;
-
-  /* skip the space */
-  return p + 1;
-}
-
 static bool
-ParseLine(Airspaces &airspace_database, TCHAR *line,
+ParseLine(Airspaces &airspace_database, StringParser<TCHAR> &&input,
           TempAirspaceType &temp_area)
 {
-  const TCHAR *value;
-
-  // Strip comments
-  auto *comment = StringFind(line, _T('*'));
-  if (comment != nullptr)
-    *comment = _T('\0');
+  double d;
 
   // Only return expected lines
-  switch (line[0]) {
+  switch (input.pop_front()) {
   case _T('D'):
   case _T('d'):
-    switch (line[1]) {
+    switch (input.pop_front()) {
     case _T('P'):
     case _T('p'):
-      value = ValueAfterSpace(line + 2);
-      if (value == nullptr)
+      if (!input.SkipWhitespace())
         break;
 
     {
       GeoPoint temp_point;
-      if (!ReadCoords(value, temp_point))
+      if (!ReadCoords(input, temp_point))
         return false;
 
       temp_area.points.push_back(temp_point);
@@ -574,20 +522,22 @@ ParseLine(Airspaces &airspace_database, TCHAR *line,
 
     case _T('C'):
     case _T('c'):
-      temp_area.radius = Units::ToSysUnit(fixed(ParseDouble(&line[2])),
-                                          Unit::NAUTICAL_MILES);
+      if (!input.ReadDouble(d) || d < 0 || d > 1000)
+        return false;
+
+      temp_area.radius = Units::ToSysUnit(d, Unit::NAUTICAL_MILES);
       temp_area.AddCircle(airspace_database);
       temp_area.Reset();
       break;
 
     case _T('A'):
     case _T('a'):
-      ParseArcBearings(line, temp_area);
+      ParseArcBearings(input, temp_area);
       break;
 
     case _T('B'):
     case _T('b'):
-      return ParseArcPoints(line, temp_area);
+      return ParseArcPoints(input, temp_area);
 
     default:
       return true;
@@ -596,58 +546,53 @@ ParseLine(Airspaces &airspace_database, TCHAR *line,
 
   case _T('V'):
   case _T('v'):
-    // Need to set these while in count mode, or DB/DA will crash
-    if ((value = StringAfterPrefixCI(StripLeft(line + 1), _T("X="))) != nullptr) {
-      if (!ReadCoords(value, temp_area.center))
+    input.Strip();
+    if (input.SkipMatchIgnoreCase(_T("X="), 2)) {
+      if (!ReadCoords(input, temp_area.center))
         return false;
-    } else if (StringAfterPrefixCI(StripLeft(line + 1), _T("D=-"))) {
+    } else if (input.SkipMatchIgnoreCase(_T("D=-"), 3)) {
       temp_area.rotation = -1;
-    } else if (StringAfterPrefixCI(StripLeft(line + 1), _T("D=+"))) {
+    } else if (input.SkipMatchIgnoreCase(_T("D=+"), 3)) {
       temp_area.rotation = +1;
     }
     break;
 
   case _T('A'):
   case _T('a'):
-    switch (line[1]) {
+    switch (input.pop_front()) {
     case _T('C'):
     case _T('c'):
-      value = ValueAfterSpace(line + 2);
-      if (value == nullptr)
+      if (!input.SkipWhitespace())
         break;
 
       temp_area.AddPolygon(airspace_database);
       temp_area.Reset();
 
-      temp_area.type = ParseType(value);
+      temp_area.type = ParseType(input.c_str());
       break;
 
     case _T('N'):
     case _T('n'):
-      value = ValueAfterSpace(line + 2);
-      if (value != nullptr)
-        temp_area.name = value;
+      if (input.SkipWhitespace())
+        temp_area.name = input.c_str();
       break;
 
     case _T('L'):
     case _T('l'):
-      value = ValueAfterSpace(line + 2);
-      if (value != nullptr)
-        ReadAltitude(value, temp_area.base);
+      if (input.SkipWhitespace())
+        ReadAltitude(input, temp_area.base);
       break;
 
     case _T('H'):
     case _T('h'):
-      value = ValueAfterSpace(line + 2);
-      if (value != nullptr)
-        ReadAltitude(value, temp_area.top);
+      if (input.SkipWhitespace())
+        ReadAltitude(input, temp_area.top);
       break;
 
     case _T('R'):
     case _T('r'):
-      value = ValueAfterSpace(line + 2);
-      if (value != nullptr)
-        temp_area.radio = value;
+      if (input.SkipWhitespace())
+        temp_area.radio = input.c_str();
       break;
 
     default:
@@ -660,6 +605,18 @@ ParseLine(Airspaces &airspace_database, TCHAR *line,
   return true;
 }
 
+static bool
+ParseLine(Airspaces &airspace_database, TCHAR *line,
+          TempAirspaceType &temp_area)
+{
+  // Strip comments
+  auto *comment = StringFind(line, _T('*'));
+  if (comment != nullptr)
+    *comment = _T('\0');
+
+  return ParseLine(airspace_database, StringParser<TCHAR>(line), temp_area);
+}
+
 static AirspaceClass
 ParseClassTNP(const TCHAR *buffer)
 {
@@ -674,7 +631,7 @@ static AirspaceClass
 ParseTypeTNP(const TCHAR *buffer)
 {
   // Handle e.g. "TYPE=CLASS C" properly
-  const TCHAR *type = StringAfterPrefixCI(buffer, _T("CLASS "));
+  const TCHAR *type = StringAfterPrefixIgnoreCase(buffer, _T("CLASS "));
   if (type) {
     AirspaceClass _class = ParseClassTNP(type);
     if (_class != OTHER)
@@ -691,39 +648,55 @@ ParseTypeTNP(const TCHAR *buffer)
 }
 
 static bool
-ParseCoordsTNP(const TCHAR *buffer, GeoPoint &point)
+ReadNonNegativeAngleTNP(StringParser<TCHAR> &input, Angle &value_r,
+                        unsigned max_degrees)
+{
+  unsigned deg, min, sec;
+  if (!input.ReadUnsigned(sec))
+    return false;
+
+  deg = sec / 10000;
+  min = (sec - deg * 10000) / 100;
+  sec = sec - min * 100 - deg * 10000;
+
+  if (deg > max_degrees || min >= 60 || sec >= 60)
+    return false;
+
+  value_r = Angle::DMS(deg, min, sec);
+  return true;
+}
+
+static bool
+ParseCoordsTNP(StringParser<TCHAR> &input, GeoPoint &point)
 {
   // Format: N542500 E0105000
   bool negative = false;
-  long deg = 0, min = 0, sec = 0;
-  TCHAR *ptr;
 
-  if (buffer[0] == _T('S') || buffer[0] == _T('s'))
+  if (input.SkipMatch('S') || input.SkipMatch('s'))
     negative = true;
+  else if (input.SkipMatch('N') || input.SkipMatch('n'))
+    negative = false;
+  else
+    return false;
 
-  sec = _tcstol(&buffer[1], &ptr, 10);
-  deg = labs(sec / 10000);
-  min = labs((sec - deg * 10000) / 100);
-  sec = sec - min * 100 - deg * 10000;
+  if (!ReadNonNegativeAngleTNP(input, point.latitude, 91))
+    return false;
 
-  point.latitude = Angle::DMS(deg, min, sec);
   if (negative)
     point.latitude.Flip();
 
-  negative = false;
+  input.Strip();
 
-  if (ptr[0] == _T(' '))
-    ptr++;
-
-  if (ptr[0] == _T('W') || ptr[0] == _T('w'))
+  if (input.SkipMatch('W') || input.SkipMatch('w'))
     negative = true;
+  else if (input.SkipMatch('E') || input.SkipMatch('e'))
+    negative = false;
+  else
+    return false;
 
-  sec = _tcstol(&ptr[1], &ptr, 10);
-  deg = labs(sec / 10000);
-  min = labs((sec - deg * 10000) / 100);
-  sec = sec - min * 100 - deg * 10000;
+  if (!ReadNonNegativeAngleTNP(input, point.longitude, 181))
+    return false;
 
-  point.longitude = Angle::DMS(deg, min, sec);
   if (negative)
     point.longitude.Flip();
 
@@ -733,7 +706,7 @@ ParseCoordsTNP(const TCHAR *buffer, GeoPoint &point)
 }
 
 static bool
-ParseArcTNP(const TCHAR *buffer, TempAirspaceType &temp_area)
+ParseArcTNP(StringParser<TCHAR> &input, TempAirspaceType &temp_area)
 {
   if (temp_area.points.empty())
     return false;
@@ -742,25 +715,21 @@ ParseArcTNP(const TCHAR *buffer, TempAirspaceType &temp_area)
 
   GeoPoint from = temp_area.points.back();
 
-  const TCHAR* parameter;
-  if ((parameter = _tcsstr(buffer, _T(" "))) == nullptr)
-    return false;
-  if ((parameter = StringAfterPrefixCI(parameter, _T(" CENTRE="))) == nullptr)
+  /* skip "RADIUS=... " */
+  if (!input.SkipWord())
     return false;
 
-  if (!ParseCoordsTNP(parameter, temp_area.center))
+  if (!input.SkipMatchIgnoreCase(_T("CENTRE="), 7))
     return false;
 
-  if ((parameter = _tcsstr(parameter, _T(" "))) == nullptr)
+  if (!ParseCoordsTNP(input, temp_area.center))
     return false;
-  parameter++;
-  if ((parameter = _tcsstr(parameter, _T(" "))) == nullptr)
-    return false;
-  if ((parameter = StringAfterPrefixCI(parameter, _T(" TO="))) == nullptr)
+
+  if (!input.SkipMatchIgnoreCase(_T(" TO="), 4))
     return false;
 
   GeoPoint to;
-  if (!ParseCoordsTNP(parameter, to))
+  if (!ParseCoordsTNP(input, to))
     return false;
 
   temp_area.AppendArc(from, to);
@@ -769,37 +738,36 @@ ParseArcTNP(const TCHAR *buffer, TempAirspaceType &temp_area)
 }
 
 static bool
-ParseCircleTNP(const TCHAR *buffer, TempAirspaceType &temp_area)
+ParseCircleTNP(StringParser<TCHAR> &input, TempAirspaceType &temp_area)
 {
   // CIRCLE RADIUS=17.00 CENTRE=N533813 E0095943
 
-  const TCHAR* parameter;
-  if ((parameter = StringAfterPrefixCI(buffer, _T("RADIUS="))) == nullptr)
+  if (!input.SkipMatchIgnoreCase(_T("RADIUS="), 7))
     return false;
-  temp_area.radius = Units::ToSysUnit(fixed(ParseDouble(parameter)),
-                                      Unit::NAUTICAL_MILES);
 
-  if ((parameter = _tcsstr(parameter, _T(" "))) == nullptr)
+  double radius;
+  if (!input.ReadDouble(radius) || radius <= 0 || radius > 1000)
     return false;
-  if ((parameter = StringAfterPrefixCI(parameter, _T(" CENTRE="))) == nullptr)
-    return false;
-  ParseCoordsTNP(parameter, temp_area.center);
 
-  return true;
+  temp_area.radius = Units::ToSysUnit(radius, Unit::NAUTICAL_MILES);
+
+  if (!input.SkipMatchIgnoreCase(_T(" CENTRE="), 8))
+    return false;
+
+  return ParseCoordsTNP(input, temp_area.center);
 }
 
 static bool
-ParseLineTNP(Airspaces &airspace_database, TCHAR *line,
+ParseLineTNP(Airspaces &airspace_database, StringParser<TCHAR> &input,
              TempAirspaceType &temp_area, bool &ignore)
 {
-  if (*line == _T('#'))
+  if (input.Match('#'))
     return true;
 
-  const TCHAR* parameter;
-  if ((parameter = StringAfterPrefixCI(line, _T("INCLUDE="))) != nullptr) {
-    if (StringStartsWithIgnoreCase(parameter, _T("YES")))
+  if (input.SkipMatchIgnoreCase(_T("INCLUDE="), 8)) {
+    if (input.MatchIgnoreCase(_T("YES"), 3))
       ignore = false;
-    else if (StringStartsWithIgnoreCase(parameter, _T("NO")))
+    else if (input.MatchIgnoreCase(_T("NO"), 2))
       ignore = true;
 
     return true;
@@ -808,53 +776,50 @@ ParseLineTNP(Airspaces &airspace_database, TCHAR *line,
   if (ignore)
     return true;
 
-  if ((parameter = StringAfterPrefixCI(line, _T("POINT="))) != nullptr) {
+  if (input.SkipMatchIgnoreCase(_T("POINT="), 6)) {
     GeoPoint temp_point;
-    if (!ParseCoordsTNP(parameter, temp_point))
+    if (!ParseCoordsTNP(input, temp_point))
       return false;
 
     temp_area.points.push_back(temp_point);
-  } else if ((parameter =
-      StringAfterPrefixCI(line, _T("CIRCLE "))) != nullptr) {
-    if (!ParseCircleTNP(parameter, temp_area))
+  } else if (input.SkipMatchIgnoreCase(_T("CIRCLE "), 7)) {
+    if (!ParseCircleTNP(input, temp_area))
       return false;
 
     temp_area.AddCircle(airspace_database);
     temp_area.ResetTNP();
-  } else if ((parameter =
-      StringAfterPrefixCI(line, _T("CLOCKWISE "))) != nullptr) {
+  } else if (input.SkipMatchIgnoreCase(_T("CLOCKWISE "), 10)) {
     temp_area.rotation = 1;
-    if (!ParseArcTNP(parameter, temp_area))
+    if (!ParseArcTNP(input, temp_area))
       return false;
-  } else if ((parameter =
-      StringAfterPrefixCI(line, _T("ANTI-CLOCKWISE "))) != nullptr) {
+  } else if (input.SkipMatchIgnoreCase(_T("ANTI-CLOCKWISE "), 15)) {
     temp_area.rotation = -1;
-    if (!ParseArcTNP(parameter, temp_area))
+    if (!ParseArcTNP(input, temp_area))
       return false;
-  } else if ((parameter = StringAfterPrefixCI(line, _T("TITLE="))) != nullptr) {
+  } else if (input.SkipMatchIgnoreCase(_T("TITLE="), 6)) {
     temp_area.AddPolygon(airspace_database);
     temp_area.ResetTNP();
 
-    temp_area.name = parameter;
-  } else if ((parameter = StringAfterPrefixCI(line, _T("TYPE="))) != nullptr) {
+    temp_area.name = input.c_str();
+  } else if (input.SkipMatchIgnoreCase(_T("TYPE="), 5)) {
     temp_area.AddPolygon(airspace_database);
     temp_area.ResetTNP();
 
-    temp_area.type = ParseTypeTNP(parameter);
-  } else if ((parameter = StringAfterPrefixCI(line, _T("CLASS="))) != nullptr) {
-    temp_area.type = ParseClassTNP(parameter);
-  } else if ((parameter = StringAfterPrefixCI(line, _T("TOPS="))) != nullptr) {
-    ReadAltitude(parameter, temp_area.top);
-  } else if ((parameter = StringAfterPrefixCI(line, _T("BASE="))) != nullptr) {
-    ReadAltitude(parameter, temp_area.base);
-  } else if ((parameter = StringAfterPrefixCI(line, _T("RADIO="))) != nullptr) {
-    temp_area.radio = parameter;
-  } else if ((parameter = StringAfterPrefixCI(line, _T("ACTIVE="))) != nullptr) {
-    if (StringIsEqualIgnoreCase(parameter, _T("WEEKEND")))
+    temp_area.type = ParseTypeTNP(input.c_str());
+  } else if (input.SkipMatchIgnoreCase(_T("CLASS="), 6)) {
+    temp_area.type = ParseClassTNP(input.c_str());
+  } else if (input.SkipMatchIgnoreCase(_T("TOPS="), 5)) {
+    ReadAltitude(input, temp_area.top);
+  } else if (input.SkipMatchIgnoreCase(_T("BASE="), 5)) {
+    ReadAltitude(input, temp_area.base);
+  } else if (input.SkipMatchIgnoreCase(_T("RADIO="), 6)) {
+    temp_area.radio = input.c_str();
+  } else if (input.SkipMatchIgnoreCase(_T("ACTIVE="), 7)) {
+    if (input.MatchAllIgnoreCase(_T("WEEKEND")))
       temp_area.days_of_operation.SetWeekend();
-    else if (StringIsEqualIgnoreCase(parameter, _T("WEEKDAY")))
+    else if (input.MatchAllIgnoreCase(_T("WEEKDAY")))
       temp_area.days_of_operation.SetWeekdays();
-    else if (StringIsEqualIgnoreCase(parameter, _T("EVERYDAY")))
+    else if (input.MatchAllIgnoreCase(_T("EVERYDAY")))
       temp_area.days_of_operation.SetAll();
   }
 
@@ -869,7 +834,7 @@ DetectFileType(const TCHAR *line)
       StringStartsWithIgnoreCase(line, _T("TITLE=")))
     return AirspaceFileType::TNP;
 
-  const TCHAR *p = StringAfterPrefixCI(line, _T("AC"));
+  const TCHAR *p = StringAfterPrefixIgnoreCase(line, _T("AC"));
   if (p != nullptr && (StringIsEmpty(p) || *p == _T(' ')))
     return AirspaceFileType::OPENAIR;
 
@@ -877,7 +842,8 @@ DetectFileType(const TCHAR *line)
 }
 
 bool
-AirspaceParser::Parse(TLineReader &reader, OperationEnvironment &operation)
+ParseAirspaceFile(Airspaces &airspaces,
+                  TLineReader &reader, OperationEnvironment &operation)
 {
   bool ignore = false;
 
@@ -911,10 +877,12 @@ AirspaceParser::Parse(TLineReader &reader, OperationEnvironment &operation)
           !ShowParseWarning(line_num, line, operation))
         return false;
 
-    if (filetype == AirspaceFileType::TNP)
-      if (!ParseLineTNP(airspaces, line, temp_area, ignore) &&
+    if (filetype == AirspaceFileType::TNP) {
+      StringParser<TCHAR> input(line);
+      if (!ParseLineTNP(airspaces, input, temp_area, ignore) &&
           !ShowParseWarning(line_num, line, operation))
         return false;
+    }
 
     // Update the ProgressDialog
     if ((line_num & 0xff) == 0)
