@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,7 +24,9 @@ Copyright_License {
 #ifndef XCSOAR_COMPATIBILITY_PATH_H
 #define XCSOAR_COMPATIBILITY_PATH_H
 
-#ifdef WIN32
+#include <tchar.h>
+
+#ifdef _WIN32
 
 #define DIR_SEPARATOR '\\'
 #define DIR_SEPARATOR_S "\\"
@@ -39,12 +41,8 @@ Copyright_License {
 static inline bool
 IsDirSeparator(TCHAR ch)
 {
-#ifdef WIN32
-#ifdef _WIN32_WCE
-  return ch == _T('/') || ch == _T('\\');
-#else
+#ifdef _WIN32
   return ch == _T('\\');
-#endif
 #else
   return ch == _T('/');
 #endif
