@@ -165,13 +165,13 @@ struct FeaturesSettings {
 
 struct CirclingSettings {
   bool external_trigger_cruise_enabled;
-  double cruise_to_circling_mode_switch_threshold;
-  double circling_to_cruise_mode_switch_threshold;
+  FloatDuration cruise_to_circling_mode_switch_threshold;
+  FloatDuration circling_to_cruise_mode_switch_threshold;
 
   void SetDefaults() {
     external_trigger_cruise_enabled = false;
-    cruise_to_circling_mode_switch_threshold = 15;
-    circling_to_cruise_mode_switch_threshold = 10;
+    cruise_to_circling_mode_switch_threshold = std::chrono::seconds{15};
+    circling_to_cruise_mode_switch_threshold = std::chrono::seconds{10};
   }
 };
 
