@@ -148,7 +148,7 @@ CirclingWind::CalcWind()
   assert(!samples.empty());
 
   // reject if average time step greater than 2.0 seconds
-  if ((samples.back().time - samples[0].time) / (samples.size() - 1) > 2)
+  if ((samples.back().time - samples[0].time) / (samples.size() - 1) > std::chrono::seconds{2})
     return Result(0);
 
   // find average
