@@ -168,13 +168,6 @@ public:
                             struct NMEAInfo &info) override;
 };
 
-/* Workaround for some GCC versions which don't inline the constexpr
-   despite being defined so in C++17, see
-   http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0386r2.pdf */
-#if GCC_OLDER_THAN(9,0)
-constexpr std::chrono::milliseconds KRT2Device::CMD_TIMEOUT;
-#endif
-
 KRT2Device::KRT2Device(Port &_port)
  : port(_port)
 {
