@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,7 +26,6 @@ Copyright_License {
 #include "Form/Button.hpp"
 #include "Form/DataField/Enum.hpp"
 #include "Form/DataField/Float.hpp"
-#include "Form/DataField/Boolean.hpp"
 #include "Interface.hpp"
 #include "Language/Language.hpp"
 #include "UIGlobals.hpp"
@@ -34,7 +33,7 @@ Copyright_License {
 
 WindSettingsPanel::WindSettingsPanel(bool _edit_manual_wind,
                                      bool _clear_manual_button,
-                                     bool _edit_trail_drift)
+                                     bool _edit_trail_drift) noexcept
   :RowFormWidget(UIGlobals::GetDialogLook()),
    edit_manual_wind(_edit_manual_wind),
    clear_manual_button(_clear_manual_button),
@@ -42,7 +41,16 @@ WindSettingsPanel::WindSettingsPanel(bool _edit_manual_wind,
    clear_manual_window(nullptr) {}
 
 void
-WindSettingsPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
+WindSettingsPanel::ClearManual() noexcept
+{
+  CommonInterface::SetComputerSettings().wind.manual_wind_available.Clear();
+  manual_modified = false;
+  UpdateVector();
+}
+
+void
+WindSettingsPanel::Prepare(ContainerWindow &parent,
+                           const PixelRect &rc) noexcept
 {
   RowFormWidget::Prepare(parent, rc);
 
@@ -86,10 +94,10 @@ WindSettingsPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
     WndProperty *wp =
       AddFloat(_("Speed"), _("Manual adjustment of wind speed."),
                _T("%.0f %s"), _T("%.0f"),
-               fixed(0),
-               Units::ToUserWindSpeed(Units::ToSysUnit(fixed(200),
+               0,
+               Units::ToUserWindSpeed(Units::ToSysUnit(200,
                                                        Unit::KILOMETER_PER_HOUR)),
-               fixed(1), false,
+               1, false,
                Units::ToUserWindSpeed(manual_wind.norm),
                this);
     DataFieldFloat &df = *(DataFieldFloat *)wp->GetDataField();
@@ -104,13 +112,13 @@ WindSettingsPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
   }
 
   if (clear_manual_button)
-    AddButton(_("Clear"), *this, CLEAR_MANUAL);
+    AddButton(_("Clear"), [this](){ ClearManual(); });
 
   UpdateVector();
 }
 
 void
-WindSettingsPanel::Show(const PixelRect &rc)
+WindSettingsPanel::Show(const PixelRect &rc) noexcept
 {
   if (edit_manual_wind) {
     UpdateVector();
@@ -121,7 +129,7 @@ WindSettingsPanel::Show(const PixelRect &rc)
 }
 
 void
-WindSettingsPanel::Hide()
+WindSettingsPanel::Hide() noexcept
 {
   RowFormWidget::Hide();
 
@@ -130,7 +138,7 @@ WindSettingsPanel::Hide()
 }
 
 bool
-WindSettingsPanel::Save(bool &_changed)
+WindSettingsPanel::Save(bool &_changed) noexcept
 {
   WindSettings &settings = CommonInterface::SetComputerSettings().wind;
   MapSettings &map_settings = CommonInterface::SetMapSettings();
@@ -155,19 +163,7 @@ WindSettingsPanel::Save(bool &_changed)
 }
 
 void
-WindSettingsPanel::OnAction(int id)
-{
-  switch (id) {
-  case CLEAR_MANUAL:
-    CommonInterface::SetComputerSettings().wind.manual_wind_available.Clear();
-    manual_modified = false;
-    UpdateVector();
-    break;
-  }
-}
-
-void
-WindSettingsPanel::OnModified(DataField &df)
+WindSettingsPanel::OnModified(DataField &df) noexcept
 {
   if (!edit_manual_wind)
     return;
@@ -186,7 +182,7 @@ WindSettingsPanel::OnModified(DataField &df)
 }
 
 void
-WindSettingsPanel::UpdateVector()
+WindSettingsPanel::UpdateVector() noexcept
 {
   if (!edit_manual_wind)
     return;
