@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -28,23 +28,21 @@ Copyright_License {
 #include "Widget/RowFormWidget.hpp"
 #include "Form/Frame.hpp"
 #include "Form/Button.hpp"
-#include "Screen/Canvas.hpp"
+#include "ui/canvas/Canvas.hpp"
 #include "Screen/Layout.hpp"
-#include "Screen/SingleWindow.hpp"
-#include "Screen/Key.h"
 #include "Form/DataField/Enum.hpp"
-#include "Form/DataField/String.hpp"
 #include "Form/DataField/Listener.hpp"
 #include "InfoBoxes/InfoBoxSettings.hpp"
 #include "InfoBoxes/InfoBoxLayout.hpp"
 #include "InfoBoxes/Content/Factory.hpp"
 #include "Look/InfoBoxLook.hpp"
 #include "Language/Language.hpp"
-#include "Util/StringAPI.hxx"
-#include "Util/StaticArray.hpp"
-#include "Compiler.h"
+#include "util/StringAPI.hxx"
+#include "util/StaticArray.hxx"
 
-#include <assert.h>
+#include <cassert>
+
+using namespace UI;
 
 static InfoBoxSettings::Panel clipboard;
 static unsigned clipboard_size;
@@ -63,24 +61,20 @@ public:
 
 protected:
   /* virtual methods from class Window */
-  virtual bool OnMouseDown(PixelScalar x, PixelScalar y) override;
-  virtual bool OnMouseDouble(PixelScalar x, PixelScalar y) override;
+  bool OnMouseDown(PixelPoint p) override;
+  bool OnMouseDouble(PixelPoint p) override;
 
   /* virtual methods from class PaintWindow */
   virtual void OnPaint(Canvas &canvas) override;
 };
 
 class InfoBoxesConfigWidget final
-  : public RowFormWidget, DataFieldListener, ActionListener {
+  : public RowFormWidget, DataFieldListener {
 
   enum Controls {
     NAME, INFOBOX, CONTENT, DESCRIPTION
   };
 
-  enum Buttons {
-    COPY, PASTE,
-  };
-
   struct Layout {
     InfoBoxLayout::Layout info_boxes;
 
@@ -91,7 +85,7 @@ class InfoBoxesConfigWidget final
     Layout(PixelRect rc, InfoBoxSettings::Geometry geometry);
   };
 
-  ActionListener &dialog;
+  WndForm &dialog;
   const InfoBoxLook &look;
 
   InfoBoxSettings::Panel &data;
@@ -106,7 +100,7 @@ class InfoBoxesConfigWidget final
   Button copy_button, paste_button, close_button;
 
 public:
-  InfoBoxesConfigWidget(ActionListener &_dialog,
+  InfoBoxesConfigWidget(WndForm &_dialog,
                         const DialogLook &dialog_look,
                         const InfoBoxLook &_look,
                         InfoBoxSettings::Panel &_data,
@@ -153,11 +147,11 @@ public:
   }
 
   /* virtual methods from class Widget */
-  void Prepare(ContainerWindow &parent, const PixelRect &rc) override;
+  void Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept override;
 
-  bool Save(bool &changed) override;
+  bool Save(bool &changed) noexcept override;
 
-  void Show(const PixelRect &rc) override {
+  void Show(const PixelRect &rc) noexcept override {
     const Layout layout(rc, geometry);
 
     RowFormWidget::Show(layout.form);
@@ -170,7 +164,7 @@ public:
       previews[i].MoveAndShow(layout.info_boxes.positions[i]);
   }
 
-  void Hide() override {
+  void Hide() noexcept override {
     RowFormWidget::Hide();
 
     copy_button.Hide();
@@ -181,7 +175,7 @@ public:
       i.Hide();
   }
 
-  void Move(const PixelRect &rc) override {
+  void Move(const PixelRect &rc) noexcept override {
     const Layout layout(rc, geometry);
 
     RowFormWidget::Move(layout.form);
@@ -191,19 +185,15 @@ public:
     close_button.Move(layout.close_button);
   }
 
-  bool SetFocus() override {
+  bool SetFocus() noexcept override {
     GetGeneric(INFOBOX).SetFocus();
     return true;
   }
 
-#ifdef GNAV
-  bool KeyPress(unsigned key_code) override;
-#endif
-
 private:
   /* virtual methods from class DataFieldListener */
 
-  void OnModified(DataField &df) override {
+  void OnModified(DataField &df) noexcept override {
     if (IsDataField(INFOBOX, df)) {
       const DataFieldEnum &dfe = (const DataFieldEnum &)df;
       SetCurrentInfoBox(dfe.GetValue());
@@ -220,19 +210,6 @@ private:
       RefreshEditContentDescription();
     }
   }
-
-  /* virtual methods from class ActionListener */
-  void OnAction(int id) override {
-    switch (id) {
-    case COPY:
-      OnCopy();
-      break;
-
-    case PASTE:
-      OnPaste();
-      break;
-    }
-  }
 };
 
 InfoBoxesConfigWidget::Layout::Layout(PixelRect rc,
@@ -253,7 +230,7 @@ InfoBoxesConfigWidget::Layout::Layout(PixelRect rc,
 
 void
 InfoBoxesConfigWidget::Prepare(ContainerWindow &parent,
-                               const PixelRect &rc)
+                               const PixelRect &rc) noexcept
 {
   const Layout layout(rc, geometry);
 
@@ -284,7 +261,7 @@ InfoBoxesConfigWidget::Prepare(ContainerWindow &parent,
   Add(_("Content"), nullptr, dfe);
 
   ContainerWindow &form_parent = (ContainerWindow &)RowFormWidget::GetWindow();
-  AddRemaining(new WndFrame(form_parent, GetLook(), rc));
+  AddRemaining(std::make_unique<WndFrame>(form_parent, GetLook(), rc));
 
   WindowStyle button_style;
   button_style.Hide();
@@ -292,14 +269,13 @@ InfoBoxesConfigWidget::Prepare(ContainerWindow &parent,
 
   const auto &button_look = GetLook().button;
   copy_button.Create(parent, button_look, _("Copy"), layout.copy_button,
-                     button_style, *this, COPY);
+                     button_style, [this](){ OnCopy(); });
   paste_button.Create(parent, button_look, _("Paste"), layout.paste_button,
-                      button_style, *this, PASTE);
+                      button_style, [this](){ OnPaste(); });
   close_button.Create(parent, button_look, _("Close"), layout.close_button,
-                      button_style, dialog, mrOK);
+                      button_style, dialog.MakeModalResultCallback(mrOK));
 
   WindowStyle preview_style;
-  preview_style.EnableDoubleClicks();
   preview_style.Hide();
 
   previews.resize(layout.info_boxes.count);
@@ -316,7 +292,7 @@ InfoBoxesConfigWidget::Prepare(ContainerWindow &parent,
 }
 
 bool
-InfoBoxesConfigWidget::Save(bool &changed_r)
+InfoBoxesConfigWidget::Save(bool &changed_r) noexcept
 {
   if (allow_name_change) {
     const auto *new_name = GetValueString(InfoBoxesConfigWidget::NAME);
@@ -396,14 +372,14 @@ InfoBoxesConfigWidget::SetCurrentInfoBox(unsigned _current_preview)
 }
 
 bool
-InfoBoxPreview::OnMouseDown(PixelScalar x, PixelScalar y)
+InfoBoxPreview::OnMouseDown(PixelPoint p)
 {
   parent->SetCurrentInfoBox(i);
   return true;
 }
 
 bool
-InfoBoxPreview::OnMouseDouble(PixelScalar x, PixelScalar y)
+InfoBoxPreview::OnMouseDouble(PixelPoint p)
 {
   parent->BeginEditing();
   return true;
@@ -421,7 +397,7 @@ InfoBoxPreview::OnPaint(Canvas &canvas)
 
   canvas.SelectHollowBrush();
   canvas.SelectBlackPen();
-  canvas.Rectangle(0, 0, canvas.GetWidth() - 1, canvas.GetHeight() - 1);
+  canvas.DrawRectangle(PixelRect{PixelSize{canvas.GetWidth() - 1, canvas.GetHeight() - 1}});
 
   InfoBoxFactory::Type type = parent->GetContents(i);
   const TCHAR *caption = type < InfoBoxFactory::NUM_TYPES
@@ -435,59 +411,9 @@ InfoBoxPreview::OnPaint(Canvas &canvas)
   canvas.Select(parent->GetInfoBoxLook().title_font);
   canvas.SetBackgroundTransparent();
   canvas.SetTextColor(is_current ? COLOR_WHITE : COLOR_BLACK);
-  canvas.DrawText(2, 2, caption);
+  canvas.DrawText({2, 2}, caption);
 }
 
-#ifdef GNAV
-
-bool
-InfoBoxesConfigWidget::KeyPress(unsigned key_code)
-{
-  /* map the Altair hardware buttons */
-  switch (key_code){
-  case KEY_UP:
-    ((DataFieldEnum &)GetDataField(INFOBOX)).Dec();
-    GetControl(INFOBOX).RefreshDisplay();
-    return true;
-
-  case KEY_DOWN:
-    ((DataFieldEnum &)GetDataField(INFOBOX)).Inc();
-    GetControl(INFOBOX).RefreshDisplay();
-    return true;
-
-  case KEY_LEFT:
-    ((DataFieldEnum &)GetDataField(CONTENT)).Dec();
-    GetControl(CONTENT).RefreshDisplay();
-    return true;
-
-  case KEY_RIGHT:
-    ((DataFieldEnum &)GetDataField(CONTENT)).Inc();
-    GetControl(CONTENT).RefreshDisplay();
-    return true;
-
-  case KEY_APP1:
-    GetControl(NAME).BeginEditing();
-    return true;
-
-  case '6':
-    dialog.OnAction(mrOK);
-    return true;
-
-  case '7':
-    OnCopy();
-    return true;
-
-  case '8':
-    OnPaste();
-    return true;
-
-  default:
-    return false;
-  }
-}
-
-#endif
-
 bool
 dlgConfigInfoboxesShowModal(SingleWindow &parent,
                             const DialogLook &dialog_look,
@@ -496,13 +422,11 @@ dlgConfigInfoboxesShowModal(SingleWindow &parent,
                             InfoBoxSettings::Panel &data_r,
                             bool allow_name_change)
 {
-  WidgetDialog dialog(dialog_look);
-  InfoBoxesConfigWidget widget(dialog, dialog_look, _look,
-                               data_r, allow_name_change, geometry);
-  dialog.CreateFull(parent, nullptr, &widget);
+  TWidgetDialog<InfoBoxesConfigWidget> dialog(WidgetDialog::Full{}, parent,
+                                              dialog_look, nullptr);
+  dialog.SetWidget(dialog, dialog_look, _look,
+                   data_r, allow_name_change, geometry);
 
   dialog.ShowModal();
-  dialog.StealWidget();
-
   return dialog.GetChanged();
 }
