@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -33,7 +33,7 @@
  */
 class DMStQuad : public ContestDijkstra {
 public:
-  DMStQuad(const Trace &_trace);
+  explicit DMStQuad(const Trace &_trace) noexcept;
 };
 
 #endif
