@@ -111,11 +111,11 @@ bool
 StartPoint::CheckExitTransition(const AircraftState &ref_now,
                                 const AircraftState &ref_last) const
 {
-  if (!constraints.open_time_span.HasBegun(RoughTime::FromSecondOfDayChecked(unsigned(ref_last.time))))
+  if (!constraints.open_time_span.HasBegun(RoughTime{ref_last.time}))
     /* the start gate is not yet open when we left the OZ */
     return false;
 
-  if (constraints.open_time_span.HasEnded(RoughTime::FromSecondOfDayChecked(unsigned(ref_now.time))))
+  if (constraints.open_time_span.HasEnded(RoughTime{ref_now.time}))
     /* the start gate was already closed when we left the OZ */
     return false;
 
