@@ -35,8 +35,8 @@ ThermalSlice::Merge(const ThermalSlice& o)
   }
   n = n_new;
 
-  const double dt_new = dt + o.dt;
-  if (dt_new > 0) {
+  const auto dt_new = dt + o.dt;
+  if (dt_new.count() > 0) {
     w_t = (w_t * dt + o.w_t * o.dt) / dt_new;
   } else {
     w_t = 0;
@@ -48,6 +48,6 @@ void
 ThermalSlice::Update(const ThermalSlice &o, const double dh)
 {
   dt = (o.time - time) * n;
-  w_t = w_n = (dt != 0) ? dh * n / dt : o.w_n;
-  dt = std::fabs(dt);
+  w_t = w_n = (dt.count() != 0) ? dh * n / dt.count() : o.w_n;
+  dt = std::chrono::abs(dt);
 }
