@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -27,10 +27,7 @@ Copyright_License {
 void
 GestureLook::Initialise()
 {
-  color = COLOR_RED;
   pen.Create(Layout::ScalePenWidth(5), color);
-
-  invalid_color = LightColor(color);
   invalid_pen.Create(Layout::ScalePenWidth(5), invalid_color);
 }
 
