@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,9 +22,9 @@ Copyright_License {
 */
 
 #include "MapWindow.hpp"
-#include "Screen/Icon.hpp"
 #include "Geo/Math.hpp"
 #include "Task/ProtectedTaskManager.hpp"
+#include "Engine/Task/TaskManager.hpp"
 #include "Engine/Task/Ordered/OrderedTask.hpp"
 #include "Renderer/TaskRenderer.hpp"
 #include "Renderer/TaskPointRenderer.hpp"
@@ -33,8 +33,6 @@ Copyright_License {
 #include "Math/Screen.hpp"
 #include "Look/MapLook.hpp"
 
-#include <stdio.h>
-
 void
 MapWindow::DrawTask(Canvas &canvas)
 {
@@ -56,7 +54,7 @@ MapWindow::DrawTask(Canvas &canvas)
 
   ProtectedTaskManager::Lease task_manager(*task);
   const AbstractTask *task = task_manager->GetActiveTask();
-  if (task && task->CheckTask()) {
+  if (task && !IsError(task->CheckTask())) {
     TaskPointRenderer::TargetVisibility target_visibility =
         IsNearSelf() ? TaskPointRenderer::ACTIVE : TaskPointRenderer::ALL;
 
@@ -91,11 +89,14 @@ MapWindow::DrawRoute(Canvas &canvas)
   const auto &route = Calculated().planned_route;
 
   const auto r_size = route.size();
-  RasterPoint p[r_size], *pp = &p[0];
-  for (auto i = route.begin(), end = route.end(); i != end; ++i, ++pp)
-    *pp = render_projection.GeoToScreen(*i);
+  constexpr std::size_t capacity = std::decay_t<decltype(route)>::capacity();
+  BulkPixelPoint p[capacity];
+  std::transform(route.begin(), route.end(), p,
+                 [this](const auto &i) {
+                   return render_projection.GeoToScreen(i);
+                 });
 
-  ScreenClosestPoint(p[r_size-1], p[r_size-2], p[r_size-1], &p[r_size-1], Layout::Scale(20));
+  p[r_size - 1] = ScreenClosestPoint(p[r_size-1], p[r_size-2], p[r_size-1], Layout::Scale(20));
 
   canvas.Select(look.task.bearing_pen);
   canvas.DrawPolyline(p, r_size);
@@ -119,40 +120,40 @@ MapWindow::DrawTaskOffTrackIndicator(Canvas &canvas)
   const GeoPoint target = current_leg.location_remaining;
   GeoVector vec(Basic().location, target);
 
-  if ((Basic().track - vec.bearing).AsDelta().AbsoluteDegrees() < fixed(10))
+  if ((Basic().track - vec.bearing).AsDelta().AbsoluteDegrees() < 10)
     // insignificant error
     return;
 
-  fixed distance_max =
+  auto distance_max =
     std::min(vec.distance,
-             render_projection.GetScreenDistanceMeters() * fixed(0.7));
+             render_projection.GetScreenDistanceMeters() * 0.7);
 
   // too short to bother
-  if (distance_max < fixed(5000))
+  if (distance_max < 5000)
     return;
 
   GeoPoint start = Basic().location;
   
-  canvas.Select(*look.overlay_font);
+  canvas.Select(*look.overlay.overlay_font);
   canvas.SetTextColor(COLOR_BLACK);
   canvas.SetBackgroundTransparent();
   
   GeoPoint dloc;
   int ilast = 0;
-  for (fixed d = fixed(1) / 4; d <= fixed(1); d += fixed(1) / 4) {
+  for (double d = 0.25; d <= 1; d += 0.25) {
     dloc = FindLatitudeLongitude(start, Basic().track, distance_max * d);
     
-    fixed distance0 = start.DistanceS(dloc);
-    fixed distance1 = target.DistanceS(dloc);
-    fixed distance = fixed(distance0 + distance1) / vec.distance;
-    int idist = iround((distance - fixed(1)) * 100);
+    double distance0 = start.DistanceS(dloc);
+    double distance1 = target.DistanceS(dloc);
+    double distance = (distance0 + distance1) / vec.distance;
+    int idist = iround((distance - 1) * 100);
     
     if ((idist != ilast) && (idist > 0) && (idist < 1000)) {
       TCHAR Buffer[5];
       _stprintf(Buffer, _T("%d"), idist);
-      RasterPoint sc = render_projection.GeoToScreen(dloc);
+      auto sc = render_projection.GeoToScreen(dloc);
       PixelSize tsize = canvas.CalcTextSize(Buffer);
-      canvas.DrawText(sc.x - tsize.cx / 2, sc.y - tsize.cy / 2, Buffer);
+      canvas.DrawText(sc - tsize / 2u, Buffer);
       ilast = idist;
     }
   }
