@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,41 +22,47 @@ Copyright_License {
 */
 
 #include "Operation/Operation.hpp"
-#include "OS/Sleep.h"
+#include "system/Sleep.h"
 
 bool
-NullOperationEnvironment::IsCancelled() const
+NullOperationEnvironment::IsCancelled() const noexcept
 {
   return false;
 }
 
 void
-NullOperationEnvironment::Sleep(unsigned ms)
+NullOperationEnvironment::SetCancelHandler(std::function<void()>) noexcept
+{
+  /* this class doesn't support cancellation, so this is a no-op */
+}
+
+void
+NullOperationEnvironment::Sleep(std::chrono::steady_clock::duration) noexcept
 {
 }
 
 void
-NullOperationEnvironment::SetErrorMessage(const TCHAR *text)
+NullOperationEnvironment::SetErrorMessage(const TCHAR *text) noexcept
 {
 }
 
 void
-NullOperationEnvironment::SetText(const TCHAR *text)
+NullOperationEnvironment::SetText(const TCHAR *text) noexcept
 {
 }
 
 void
-NullOperationEnvironment::SetProgressRange(unsigned range)
+NullOperationEnvironment::SetProgressRange(unsigned range) noexcept
 {
 }
 
 void
-NullOperationEnvironment::SetProgressPosition(unsigned position)
+NullOperationEnvironment::SetProgressPosition(unsigned position) noexcept
 {
 }
 
 void
-QuietOperationEnvironment::Sleep(unsigned ms)
+QuietOperationEnvironment::Sleep(std::chrono::steady_clock::duration duration) noexcept
 {
-  ::Sleep(ms);
+  ::Sleep(std::chrono::duration_cast<std::chrono::milliseconds>(duration).count());
 }
