@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,13 +22,13 @@ Copyright_License {
 */
 
 #include "BitmapButtonRenderer.hpp"
-#include "Screen/Canvas.hpp"
-#include "Screen/Bitmap.hpp"
+#include "ui/canvas/Canvas.hpp"
+#include "ui/canvas/Bitmap.hpp"
 
 unsigned
 BitmapButtonRenderer::GetMinimumButtonWidth() const
 {
-  return bitmap.GetSize().cx;
+  return bitmap.GetSize().width;
 }
 
 void
