@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -31,6 +31,9 @@ class Canvas;
 struct ChartLook;
 class GlidePolar;
 class FlightStatistics;
+struct NMEAInfo;
+struct DerivedInfo;
+class TaskManager;
 
 void
 ClimbChartCaption(TCHAR *buffer,
@@ -40,6 +43,9 @@ void
 RenderClimbChart(Canvas &canvas, const PixelRect rc,
                  const ChartLook &chart_look,
                  const FlightStatistics &fs,
-                 const GlidePolar &glide_polar);
+                 const GlidePolar &glide_polar,
+                 const NMEAInfo &nmea_info,
+                 const DerivedInfo &derived_info,
+                 const TaskManager &task);
 
 #endif
