@@ -30,6 +30,10 @@
 #ifndef MAPERROR_H
 #define MAPERROR_H
 
+#ifdef SHAPELIB_DISABLED
+#include "mapthread.h"
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -46,7 +50,6 @@ extern "C" {
 #define MS_REGEXERR 5
 #define MS_TTFERR 6
 #define MS_DBFERR 7
-#define MS_GDERR 8
 #define MS_IDENTERR 9
 #define MS_EOFERR 10
 #define MS_PROJERR 11
@@ -59,7 +62,7 @@ extern "C" {
 #define MS_NOTFOUND 18 /* empty search results */
 #define MS_SHPERR 19
 #define MS_PARSEERR 20
-#define MS_SDEERR 21
+#define MS_UNUSEDERR 21
 #define MS_OGRERR 22
 #define MS_QUERYERR 23
 #define MS_WMSERR 24      /* WMS server error */
@@ -79,8 +82,9 @@ extern "C" {
 #define MS_NULLPARENTERR 38
 #define MS_AGGERR 39
 #define MS_OWSERR 40
-#define MS_OGLERR 42
-#define MS_RENDERERERR 43
+#define MS_OGLERR 41
+#define MS_RENDERERERR 42
+#define MS_V8ERR 43  
 #define MS_NUMERRORCODES 44
 
 #define MESSAGELENGTH 2048
@@ -109,6 +113,7 @@ extern "C" {
     char routine[ROUTINELENGTH];
     char message[MESSAGELENGTH];
     int isreported;
+    int errorcount; /* number of subsequent errors */
 #ifndef SWIG
     struct errorObj *next;
 #endif
@@ -144,7 +149,8 @@ extern "C" {
                  MS_DEBUGLEVEL_TUNING     = 2,  /* Reports timing info */
                  MS_DEBUGLEVEL_V          = 3,  /* Verbose */
                  MS_DEBUGLEVEL_VV         = 4,  /* Very verbose */
-                 MS_DEBUGLEVEL_VVV        = 5   /* Very very verbose */
+                 MS_DEBUGLEVEL_VVV        = 5,  /* Very very verbose */
+                 MS_DEBUGLEVEL_DEVDEBUG   = 20, /* Undocumented, will trigger debug messages only useful for developers */
                } debugLevel;
 
 #ifndef SWIG
@@ -162,7 +168,7 @@ extern "C" {
     char        *errorfile;
     FILE        *fp;
     /* The following 2 members are used only with USE_THREAD (but we won't #ifndef them) */
-    int         thread_id;
+    void* thread_id;
     struct debug_info_obj *next;
   } debugInfoObj;
 
