@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -27,11 +27,16 @@ Copyright_License {
 #include "NOAAStore.hpp"
 
 class JobRunner;
+class CurlGlobal;
 
-namespace NOAAUpdater
-{
-  bool Update(NOAAStore &store, JobRunner &runner);
-  bool Update(NOAAStore::Item &item, JobRunner &runner);
-};
+namespace NOAAUpdater {
+
+bool
+Update(NOAAStore &store, CurlGlobal &curl, JobRunner &runner);
+
+bool
+Update(NOAAStore::Item &item, CurlGlobal &curl, JobRunner &runner);
+
+}
 
 #endif
