@@ -30,6 +30,7 @@
 #include "Geo/GeoVector.hpp"
 #include "Formatter/AirspaceFormatter.hpp"
 #include "system/FileUtil.hpp"
+#include "util/ConvertString.hpp"
 
 #include <stdlib.h>
 #include <fstream>
@@ -133,7 +134,7 @@ public:
   void Visit(const AbstractAirspace &as) {
     if (do_report) {
       *fout << as;
-      *fout << "# Name: " << as.GetName()
+      *fout << "# Name: " << WideToUTF8Converter(as.GetName())
             << "Base: " << as.GetBase()
             << " Top: " << as.GetTop()
             << "\n";
